Introduction
============

WSIData is data structure for storing and manipulating whole slide images (WSI).
It provides a high-level interface to WSI files, allowing users to easily extract and manipulate image data and store
the analysis results in SpatialData format.


.. toctree::
   :maxdepth: 2
   :hidden:

   01-read&write
   02-accessors


.. grid:: 2

    .. grid-item-card:: Open a WSI
       :link: 01-read&write
       :link-type: doc

       Open a whole slide image and save it in SpatialData format.

    .. grid-item-card:: Accessors for WSIData
       :link: 02-accessors
       :link-type: doc

       What are accessors and how to use them?
